String.prototype.toTitleCase = function() {
	return this.replace(/\w\S*/g, function(txt) {
		return txt.charAt(0).toUpperCase() + txt.substr(1).toLowerCase();
	});
}

String.prototype.toSentenceCase = function() {
	return this.charAt(0).toUpperCase() + this.substr(1).toLowerCase();
}

String.prototype.toContent = function() {
	return this.replace(/-/g, " ");
}

const copyColourFallback = (copyInfo, attr) => {
	console.log("fallback")
	var textArea = document.createElement('textarea');
	textArea.value = copyInfo;

	// Avoid scrolling to bottom
	textArea.style.top = '0';
	textArea.style.left = '0';
	textArea.style.position = 'fixed';

	document.body.appendChild(textArea);
	textArea.focus();
	textArea.select();

	try {
		var successful = document.execCommand('copy');
		setTimeout(function () {
			if (successful) {
				//copyInfo.success();
				showMessage(`Copied ${attr}.`)
			} else {
				//copyInfo.error();
				showMessage(`Copy failed (${attr}).`, false)
			}
		}, 1);
	} catch (err) {
		setTimeout(function () {
			showMessage(`Copy failed (${attr}). ${err.Message}`, false);
			
			//copyInfo.error(err);
		}, 1);
	}
	document.body.removeChild(textArea);
}

const showMessage = (m, s) => {
	s = s == undefined ? true : s;
	console.log("Copy success (navigator.clipboard)");
	$("body").prepend("<div id='copystatus' style='display: none;'><div class='"+(s ? "succeeded" : "failed")+"'>" + m + "</div></div>");
	$("#copystatus > div").css("top", (window.scrollY + 100)+ "px");
	$("#copystatus").fadeIn(1000, function(){
		$(this).fadeOut( 1000, function() {
			$(this).remove();
		});
	})
}

const getURLVars = () => {
	var oResult = {};
	if (location.search.length > 0) {
		var aQueryString = (location.search.substr(1)).split("&");
		for (var i = 0; i < aQueryString.length; i++) {
			var aTemp = aQueryString[i].split("=");
			if (aTemp[1].length > 0) {
				oResult[aTemp[0]] = decodeURIComponent(aTemp[1].replace(/\+/g, '%20'));
			}
		}
	}
	return oResult;
}

module.exports = {
	url: getURLVars(),
	cookie: {	
		set: (name, value, expires, path, domain, secure) => {
			switch(typeof expires) {
				case "number" : 
					var d = new Date()
					expires = d.setTime(d + (expires*24*60*60*1000));
				break;
				case "object" : 
					expires = expires.toGMTString();
			}
			document.cookie= name + "=" + escape(value) +
				((expires) ? "; expires=" + expires : "") +
				("; path=/") +
				((domain) ? "; domain=" + domain : "") +
				((secure) ? "; secure" : "");
		},
		get: (cname) => {
			var name = cname + "=";
			var ca = document.cookie.split(";");
			for(var i = 0; i <ca.length; i++) {
				var c = ca[i];
				while (c.charAt(0)===" ") {
					c = c.substring(1);
				}
				if (c.indexOf(name) === 0) {
					return c.substring(name.length,c.length);
				}
			}
			return "";
		},
		remove: (cnane) => {
			setCookie(cname, "", -1);
		},
	},
	colour: {
		// showMessage: (m, s) => {
		// 	showMessage(m, s);
		// },
		copy:  (w, t) => {
			let c = t.parent().attr("data-" + (w=="var" ? "token" : w));
			c = w == "var" ? `var(${c})` : c;

			if (navigator.clipboard) {
				navigator.clipboard.writeText(c).then(function() {
					showMessage(`Copied ${w}.`);
				}, function(e) {
					copyColourFallback(c,w);
				});
			} else {
				copyColourFallback(c, w);
			}
		},
		positionTooltip: () => {
			$("color-pill > span").each(function(){
				if ((Number($("p").css('font-size').replace("px","")) * 10)  > $(this).offset().left) {
					$(this).children("div.tooltip-tc").attr("tip-position", "right");
				} else {
					$(this).children("div.tooltip-tc").attr("tip-position", "bottom");
				}
			})
		}
	},
	init: (callback) => {


		callback();
	}
};